@@ -157,7 +157,7 @@ pref("keyword.URL", "chrome://browser-region/locale/region.properties");
 
 pref("general.useragent.locale", "en-US");
 pref("general.skins.selectedSkin", "classic/1.0");
-pref("general.useragent.extra.firefox", "Firefox/2.0.0.18");
+pref("general.useragent.extra.firefox", "Firefox/2.0.0.19");
 
 pref("general.smoothScroll", false);
 //@line 169 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-53.EL_Depend/mozilla/browser/app/profile/firefox.js"
@@ -463,7 +463,7 @@ pref("browser.feeds.handler", "ask");
 
 //@line 496 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-53.EL_Depend/mozilla/browser/app/profile/firefox.js"
 // Safe browsing does nothing unless both these prefs are set.
-pref("browser.safebrowsing.enabled", true);
+pref("browser.safebrowsing.enabled", false);
 pref("browser.safebrowsing.remoteLookups", false);
 
 // Non-enhanced mode (local url lists) URL list to check for updates
